import { Product } from './product/product';
import { Store } from './store/store';
import { TokenHandler } from './auth/tokenHandler';
import { Order } from './order/order';
import { Promotion } from './promotion/promotion';
import { Recipe } from './recipe/recipe';
import { User } from './user/user';
import { Category } from './category/category';
import { List } from './list/list';
export declare class Jumbo {
    private readonly username?;
    private readonly password?;
    private readonly verbose?;
    private readonly client;
    jumboCategory: Category;
    jumboList: List;
    jumboOrder: Order;
    jumboProduct: Product;
    jumboPromotion: Promotion;
    jumboRecipe: Recipe;
    jumboStore: Store;
    jumboUser: User;
    tokenHandler?: TokenHandler;
    constructor(username?: string | undefined, password?: string | undefined, verbose?: boolean | undefined);
    category(): Category;
    list(): List;
    order(): Order;
    product(): Product;
    promotion(): Promotion;
    recipe(): Recipe;
    store(): Store;
    user(): User;
    /**
     * Function that creates a new TokenHandler for given username and password
     * @param username Jumbo account username (e-mail)
     * @param password Jumbo account password
     */
    login(username: string, password: string): void;
    /**
     * PUT request
     * @param path Endpoint URL (without start)
     * @param body Body of PUT (if any)
     * @param extraHeaders Any extra headers
     * @param query Any query options
     * @param authRequired Whether a token is required for the function
     * @param fullResponse Returns response + headers instead of only data
     */
    put(path: string, body?: any, extraHeaders?: Headers, query?: Query, authRequired?: boolean, fullResponse?: boolean): Promise<any>;
    /**
     * POST request
     * @param path Endpoint URL (without start)
     * @param body Body of POST
     * @param extraHeaders Any extra headers
     * @param query Any query options
     * @param authRequired Whether a token is required for the function
     * @param fullResponse Returns response + headers instead of only data
     */
    post(path: string, body: any, extraHeaders?: Headers, query?: Query, authRequired?: boolean, fullResponse?: boolean): Promise<any>;
    /**
     * GET request
     * @param path Endpoint URL (without start)
     * @param extraHeaders Any extra headers
     * @param query Any query options
     * @param authRequired Whether a token is required for the function
     * @param fullResponse Returns response + headers instead of only data
     */
    get(path: string, extraHeaders?: Headers, query?: Query, authRequired?: boolean, fullResponse?: boolean): Promise<any>;
    /**
     * Generic request method
     * @param path Endpoint URL (without start)
     * @param method Request method (GET, POST, PUT, DELETE)
     * @param body Body in case of POST and PUT
     * @param extraHeaders Any extra headers (Content-Type and Accept) are already included
     * @param query Query in case of GET
     * @param authRequired Whether a token is required for the function
     * @param fullResponse Returns response + headers instead of only data
     */
    request(path: string, method: requestMethod, body?: any, extraHeaders?: Headers, query?: Query, authRequired?: boolean, fullResponse?: boolean): Promise<any>;
    /**
     * Helper function to create headers for request
     * @param extraHeaders Any extra header options
     */
    createHeader(authRequired?: boolean, extraHeaders?: Headers): Headers;
    /**
     * Helper function to create request URL
     * @param path Path to endpoint (without ENDPOINT in .env)
     * @param query Any query options
     */
    createURL(path: string, query?: Query): string;
}
/**
 * Simple enum for different request methods
 */
export declare enum requestMethod {
    GET = "GET",
    POST = "POST",
    PUT = "PUT"
}
/**
 * Query interface that is converted to {@URLSearchParams}
 */
export interface Query {
    [key: string]: string;
}
export interface Headers {
    [key: string]: string;
}
