import { JumboObject } from '../base/jumboObject';
import { Query, Headers } from '../jumbo';
import { ListItemsModel } from './listItemsModel';
import { ListModel, ListQueryModel } from './listModel';
import { PublicListsModel } from './publicListsModel';
export declare class List extends JumboObject {
    /**
     * Returns all of your lists (login required)
     */
    getMyLists(headers?: Headers, query?: Query): Promise<ListQueryModel>;
    /**
     * Returns a single list given a list ID
     * @param listId ID of list
     */
    getListFromId(listId: string, headers?: Headers, query?: Query): Promise<ListModel>;
    /**
     * Returns a list of lists that match the given name (name is case sensitive and very specific)
     * @param listName Name of list (category)
     * @param offset Offset in search (default 0)
     * @param limit Amount of lists to retrieve (default 10)
     */
    getListsByName(listName: string, offset?: number, limit?: number, headers?: Headers, query?: Query): Promise<ListQueryModel>;
    /**
     * Shortcut function to get the most popular lists
     * @param offset Offset in search (default 0)
     * @param limit Amount of lists to retrieve (default 10)
     */
    getPopularLists(offset?: number, limit?: number, headers?: Headers, query?: Query): Promise<ListQueryModel>;
    /**
     * Gets all items from a given list
     * @param listId ID of list
     * @param offset Offset in search (default 0)
     * @param limit Amount of items to retrieve (default 10)
     */
    getItemsFromList(listId: string, offset?: number, limit?: number, headers?: Headers, query?: Query): Promise<ListItemsModel>;
    /**
     * Gets all smart lists (i.e. last purchased) of user (login required)
     */
    getMySmartLists(headers?: Headers, query?: Query): Promise<PublicListsModel>;
    /**
     * Gets all the lists the user currently follows (login required)
     */
    getMyFollowedLists(headers?: Headers, query?: Query): Promise<PublicListsModel>;
    /**
     * Checks whether the user is following the given list (login required)
     * @param listId ID of list
     */
    isFollowingList(listId: string, headers?: Headers, query?: Query): Promise<boolean>;
    /**
     * Makes the user follow the given list (login required)
     * @param listId ID of list to follow
     */
    followList(listId: string, headers?: Headers, query?: Query): Promise<any>;
    /**
     * Makes the user unfollow the given list (login required)
     * @param listId ID of list to unfollow
     */
    unfollowList(listId: string, headers?: Headers, query?: Query): Promise<any>;
}
