import { Query, Headers } from '../jumbo';
import { JumboObject } from '../base/jumboObject';
import { OrderModel } from './orderModel';
export declare class Order extends JumboObject {
    /**
     * Gets order from ID
     * @param orderId Order ID
     */
    getMyOrderById(orderId: number, headers?: Headers, query?: Query): Promise<OrderModel>;
    /**
     * Returns all the users' orders
     * @param offset Offset (default 0)
     * @param count Amount of orders (default 10)
     */
    getMyOrders(offset?: number, count?: number, headers?: Headers, query?: Query): Promise<OrderModel[]>;
    /**
     * Shortcut function to return latest (first) order
     */
    getMyLatestOrder(headers?: Headers, query?: Query): Promise<OrderModel>;
    /**
     * Returns all of the user's orders with a certain status
     * @param status Status of the order (Processing, Open, Completed)
     */
    getMyOrdersByStatus(status: OrderStatus, headers?: Headers, query?: Query): Promise<OrderModel[]>;
    /**
     * Shortcut function to retrieve the latest order that matches the status
     * @param status Status of the order
     */
    getMyLatestOrderByStatus(status: OrderStatus, headers?: Headers, query?: Query): Promise<OrderModel>;
    /**
     * Gets the user's relevant orders (which includes shipping time)
     */
    getMyRelevantOrders(headers?: Headers, query?: Query): Promise<OrderModel[]>;
    /**
     * Converts response to actual data by first converting unix timestamps to dates
     * @param order OrderResponse to convert
     */
    private convertOrderResponseToOrderModel;
    /**
     * Converts shipping unix timestamps of order to actual dates
     * @param shipping order.data.shipping
     */
    private convertShippingTimesToDates;
    /**
     * Converts delivery unix timestamps of order to actual dates
     * @param delivery order.data.delivery
     */
    private convertDeliveryTimesToDates;
    /**
     * Converts given unix timestamp to a Date
     */
    private convertUnixDateToDate;
    /**
     * Strips the last 3 digits off the timestamp to properly convert
     */
    private formatUnixTimestamp;
}
export declare enum OrderStatus {
    Processing = "PROCESSING",
    Open = "OPEN",
    ReadyToDeliver = "READY_TO_DELIVER",
    Completed = "PICKED_UP"
}
