import { Headers, Query } from '../jumbo';
import { JumboObject } from '../base/jumboObject';
import { ProductModel } from './productModel';
import { ProductSortOptions } from './productQueryModel';
export declare class Product extends JumboObject {
    /**
     * Gets product from ID
     * @param productId Product ID
     */
    getProductFromId(productId: string, headers?: Headers, query?: Query): Promise<ProductModel>;
    /**
     * Get products from given product name
     * @param productName Product name to search for
     * @param offset Offset in search (default 0)
     * @param limit Amount of products returned (default 10)
     * @param filters Any extra filters (in the form of a number)
     * @param sort Sort options as defined in ./productModel
     */
    getProductsFromName(productName: string, offset?: number, limit?: number, filters?: number, sort?: ProductSortOptions, headers?: Headers, query?: Query): Promise<ProductModel[]>;
    /**
     * Shortcut function to get the first product when searching for name
     * @param productName Product name to search for
     * @param sort Sort options as defined in ./productModel
     */
    getFirstProductFromName(productName: string, sort?: ProductSortOptions, headers?: Headers, query?: Query): Promise<ProductModel>;
}
