import { Headers, Query } from '../jumbo';
import { RecipeModel } from './recipeModel';
import { JumboObject } from '../base/jumboObject';
export declare class Recipe extends JumboObject {
    /**
     * Get recipe from ID
     * @param recipeId Recipe ID
     */
    getRecipeFromId(recipeId: number, headers?: Headers, query?: Query): Promise<RecipeModel>;
    /**
     * Get recipes from given recipe name
     * @param recipeName Recipe name to search for
     * @param offset Offset in search (default 0)
     * @param count Amount of recipes returned (default 10)
     */
    getRecipesFromName(recipeName: string, offset?: number, count?: number, headers?: Headers, query?: Query): Promise<RecipeModel[]>;
    /**
     * Shortcut function to get the first recipe when searching for name
     * @param recipeName Recipe name to search for
     */
    getFirstRecipeFromName(recipeName: string, headers?: Headers, query?: Query): Promise<RecipeModel>;
    /**
     * Get recipes from given filter ID
     * @param filterId Recipe filter ID
     * @param offset Offset in search (default 0)
     * @param count Amount of recipes returned (default 10)
     */
    getRecipesFromFilterId(filterId: number, offset?: number, count?: number, headers?: Headers, query?: Query): Promise<RecipeModel[]>;
}
